# read version from installed package
from importlib.metadata import version

__version__ = version("rcer_iot_client_pkg")

from .services.epii.api import EpiiAPI
from .general_types.api.update_thies_data_types import EpiiAPIConfig

__all__ = ["EpiiAPI", "EpiiAPIConfig"]



SHAREPOINT_BASE_URL = "/sites/uc365_CentrosyEstacionesRegionalesUC/Shared Documents/General/Test_Raspberry/THIES"
SHAREPOINT_THIES_FOLDERS = ["AVG", "EXT"]

FTP_SERVER_PATH_AVG_FILES = "ftp/thies/BINFILES/ARCH_AV1"
FTP_SERVER_PATH_EXT_FILES = "ftp/thies/BINFILES/ARCH_EX1"



from typing import Any

from rcer_iot_client_pkg.libs.zero_dependency.utils.datetime_utils import (
    datetime_to_str,
    today,
)


def parse_execute_response(
    file_contents: dict[str, Any],
) -> dict[str, dict[str, int | str]]:
    return {
        filename: {
            "size": len(data),
            "date": datetime_to_str(today()),
        }
        for filename, data in file_contents.items()
    }



from dataclasses import dataclass, field
from typing import Dict


@dataclass
class FtpClientConfig:
    ftp_host: str
    ftp_port: int
    ftp_user: str
    ftp_password: str


@dataclass
class SharepointConfig:
    sharepoint_client_id: str
    sharepoint_client_secret: str
    sharepoint_tenant_id: str
    sharepoint_tenant_name: str
    sharepoint_site_name: str


@dataclass
class UpdateThiesDataUseCaseInput:
    ftp_config: FtpClientConfig
    sharepoint_config: SharepointConfig


@dataclass
class UpdateThiesDataUseCaseOutput:
    message: str
    status: int = 0
    metadata: Dict[str, str] = field(default_factory=dict)



from dataclasses import dataclass, field
from typing import Dict
from rcer_iot_client_pkg.general_types.api.update_thies_data_types import EpiiAPIConfig


@dataclass
class UpdateThiesDataControllerInput:
    config: EpiiAPIConfig


@dataclass
class UpdateThiesDataControllerOutput:
    message: str
    status: int
    metadata: Dict[str, str] = field(default_factory=dict)
